@@ -15,6 +15,8 @@ Use Thought to describe your thoughts about the question you have been asked.
 Use Action to run one of the actions available to you - then return PAUSE.
 Observation will be the result of running those actions.
 
+Your output should be at most 1 or 2 lines long.
+
 Your available actions are:
 
 calculate:
@@ -87,6 +89,8 @@ def query(question, model, is_verbose):
             print("Observation:", observation)
             next_prompt = "Observation: {}".format(observation)
         else:
+            if is_verbose:
+                print("no action to run")
             return
 
 
